# Knockr 🚪

<a href="https://pypi.org/project/knockr" target="_blank">
    <img src="https://img.shields.io/pypi/v/knockr?color=%2334D058&label=pypi%20package" alt="Package version">
</a>
<a href="https://github.com/valentincalomme/knockr/actions/workflows/ci.yml" target="_blank">
    <img src="https://github.com/valentincalomme/knockr/actions/workflows/ci.yml/badge.svg" alt="CI">
</a>
<a href="https://pypi.org/project/knockr" target="_blank">
    <img src="https://img.shields.io/pypi/pyversions/knockr.svg?color=%2334D058" alt="Supported Python versions">
</a>
<a href="https://github.com/astral-sh/uv" target="_blank">
    <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json" alt="uv">
</a>
<a href="https://github.com/astral-sh/ruff" target="_blank">
    <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json" alt="ruff">
</a>
<a href="https://squidfunk.github.io/mkdocs-material/" target="_blank">
    <img src="https://img.shields.io/badge/Material_for_MkDocs-526CFE?style=for-the-badge&logo=MaterialForMkDocs&logoColor=white" alt="Built with Material for MkDocs">
</a>

A simple Python tool to quickly check if URLs are live and accessible.
